@@ -65,10 +65,7 @@ pub mod cpu {
 
     sysctl.arg("-n");
     sysctl.arg("machdep.cpu.brand_string");
-
-    unsafe {
-      return std::str::from_utf8_unchecked(&sysctl.output().map_or(Vec::from("unknown"), |x| x.stdout)).trim().to_string();
-    }
+    return std::str::from_utf8(&sysctl.output().map_or(Vec::from("unknown"), |x| x.stdout)).unwrap().trim().to_string();
   }
 
   pub fn windows() -> String {
@@ -78,16 +75,14 @@ pub mod cpu {
     wmi.arg("get");
     wmi.arg("name");
 
-    unsafe {
-      return match wmi.output() {
-        Err(_) => String::from("unknown"),
+    return match wmi.output() {
+      Err(_) => String::from("unknown"),
 
-        Ok(x) => {
-          let x = String::from_utf8_unchecked(x.stdout);
-          return x.lines().nth(2).unwrap_or("unknown").trim().to_string();
-        },
-      };
-    }
+      Ok(x) => {
+        let x = String::from_utf8_lossy(&x.stdout);
+        return x.lines().nth(1).unwrap_or("unknown").trim().to_string();
+      },
+    };
   }
 
   pub fn linux() -> String {
@@ -243,9 +238,10 @@ pub mod reporter {
       s.push_str(&format!("summary\n  {}", baseline.name));
 
       for b in benchmarks.iter().filter(|b| *b != baseline) {
+        let faster = b.stats.avg >= baseline.stats.avg;
         let diff = f64::from_str(&format!("{:.2}", 1.0 / baseline.stats.avg * b.stats.avg)).unwrap();
         let inv_diff = f64::from_str(&format!("{:.2}", 1.0 / b.stats.avg * baseline.stats.avg)).unwrap();
-        s.push_str(&format!("\n   {}x times {} than {}", if diff > 1.0 { diff } else { inv_diff }, if diff > 1.0 { "slower" } else { "faster" }, b.name));
+        s.push_str(&format!("\n   {}x times {} than {}", if faster { diff } else { inv_diff }, if faster { "faster" } else { "slower" }, b.name));
       }
     }
 
@@ -256,7 +252,6 @@ pub mod reporter {
         let faster = b.stats.avg >= baseline.stats.avg;
         let diff = f64::from_str(&format!("{:.2}", 1.0 / baseline.stats.avg * b.stats.avg)).unwrap();
         let inv_diff = f64::from_str(&format!("{:.2}", 1.0 / b.stats.avg * baseline.stats.avg)).unwrap();
-
         s.push_str(&format!("\n   {}x times {} than {}", if faster { fmt::color(&format!("{}", diff), fmt::Color::Green) } else { fmt::color(&format!("{}", inv_diff), fmt::Color::Red) }, if faster { "faster" } else { "slower" }, fmt::bold(&fmt::color(&b.name, fmt::Color::Cyan))));
       }
     }
